Module cron

Module cron 

Cron job scheduling for RustyClaw.

Provides a simple job scheduler that persists jobs to disk and can trigger agent turns or system events on schedule.

Structs

CronJob
A cron job definition.
CronJobPatch
Patch for updating a cron job.
CronStore
Cron job store that persists jobs to disk.
Delivery
Delivery configuration for isolated jobs.
RunEntry
Run history entry.

Enums

DeliveryMode
Delivery mode.
Payload
Payload kinds for cron jobs.
RunStatus
Run status.
Schedule
Schedule kinds for cron jobs.
SessionTarget
Session target for job execution.

Type Aliases

JobId
Unique identifier for a cron job.