Protocol types for gateway WebSocket communication.
This module provides typed frame definitions for binary serialization using bincode. The client and server are compiled together, so they share the exact same types.
Binary Protocol
Frames are serialized using bincode and sent as WebSocket Binary messages. Each frame has a type enum as the first field to allow dispatch. Text frames are not supported and will be rejected.
Re-exports
pub use frames::ClientFrame;pub use frames::ClientFrameType;pub use frames::ClientPayload;pub use frames::SecretEntryDto;pub use frames::ServerFrame;pub use frames::ServerFrameType;pub use frames::ServerPayload;pub use frames::StatusType;pub use frames::TaskInfoDto;pub use frames::ThreadInfoDto;pub use frames::deserialize_frame;pub use frames::serialize_frame;