macro_rules! parse_binary_client_frame {
($bytes:expr) => { ... };
}Expand description
Helper to parse a client frame from binary WebSocket message bytes.
macro_rules! parse_binary_client_frame {
($bytes:expr) => { ... };
}Helper to parse a client frame from binary WebSocket message bytes.