IsolationMode

Enum IsolationMode 

pub enum IsolationMode {
    PerGroup,
    Shared,
    PerUser,
}
How group conversations are isolated from each other.

Variants



PerGroup

Each group gets its own conversation history and context.



Shared

All groups share the same conversation history.



PerUser

Each user in each group gets their own context.