Module process_manager

Module process_manager 

Background process session management for RustyClaw.

Provides a registry of background exec sessions that can be polled, written to, and killed by the agent.

Uses Tokio’s async process handling for cross-platform non-blocking I/O, but exposes a sync API for compatibility with the sync tool execute interface.

Structs

ExecSession
A background exec session.
ProcessManager
Global process session manager.

Enums

SessionStatus
Status of a background session.

Functions

new_shared_manager
Create a new shared process manager.
translate_keys
Translate a space-separated list of named keys into raw bytes.

Type Aliases

SessionId
Unique identifier for a background session.
SharedProcessManager
Thread-safe process manager.