Module frames

Module frames 

Frame types and serialization for gateway protocol.

This module contains the shared types used by both client and server.

Structs

ClientFrame
Generic client frame envelope.
SecretEntryDto
DTO for secret entries in list results.
ServerFrame
Generic server frame envelope.

Enums

ClientFrameType
Incoming frame types from client to gateway.
ClientPayload
Payload variants for client frames.
ServerFrameType
Outgoing frame types from gateway to client.
ServerPayload
Payload variants for server frames.
StatusType
Status frame sub-types.

Functions

deserialize_frame
Deserialize a frame from binary using bincode with serde.
serialize_frame
Serialize a frame to binary using bincode with serde.