Pre-compaction memory flush.
Triggers a silent agent turn before compaction to persist durable memories. This prevents important context from being lost when conversation history is compacted to fit within the model’s context window.
Structs
- Memory
Flush - Memory flush controller.
- Memory
Flush Config - Configuration for pre-compaction memory flush.