pub struct SubtaskRegistry { /* private fields */ }Expand description
Registry of active subtask handles for a session.
This is used by the gateway to track all running subtasks and allow the agent to list, join, or cancel them.
Implementations
Sourceimpl SubtaskRegistry
impl SubtaskRegistry
Sourcepub fn register<T: Send + 'static>(
&mut self,
handle: &SubtaskHandle<T>,
label: impl Into<String>,
)
pub fn register<T: Send + 'static>( &mut self, handle: &SubtaskHandle<T>, label: impl Into<String>, )
Register a subtask. Call this after spawning.
Sourcepub fn cancel(&mut self, thread_id: &ThreadId) -> bool
pub fn cancel(&mut self, thread_id: &ThreadId) -> bool
Cancel a subtask by thread ID (cooperative via CancellationToken).
Sourcepub fn cancel_all(&mut self)
pub fn cancel_all(&mut self)
Cancel all subtasks (cooperative via CancellationToken).