pub async fn execute_tool(
name: &str,
args: &Value,
workspace_dir: &Path,
) -> Result<String, String>Expand description
Find a tool by name and execute it with the given arguments.
Tools with async implementations are called directly. Other tools run on a blocking thread pool to avoid blocking the async runtime.